[][src]Struct zmq::CurveKeyPair

pub struct CurveKeyPair {
    pub public_key: [u8; 32],
    pub secret_key: [u8; 32],
}

A CURVE key pair generated by 0MQ.

Note that for API consistency reasons, since version 0.9, the key pair is represented in the binary form. This is in contrast to libzmq, which returns the z85-encoded representation.

Fields

Methods

impl CurveKeyPair
[src]

Create a new key pair.