[−]Struct zmq::PollEvents
Type representing pending socket events.
Methods
impl PollEvents
impl PollEventspub fn empty() -> PollEvents
pub fn empty() -> PollEventsReturns an empty set of flags.
pub fn all() -> PollEvents
pub fn all() -> PollEventsReturns the set containing all flags.
pub fn bits(&self) -> i16
pub fn bits(&self) -> i16Returns the raw value of the flags currently stored.
pub fn from_bits(bits: i16) -> Option<PollEvents>
pub fn from_bits(bits: i16) -> Option<PollEvents>Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: i16) -> PollEvents
pub fn from_bits_truncate(bits: i16) -> PollEventsConvert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> boolReturns true if no flags are currently stored.
pub fn is_all(&self) -> bool
pub fn is_all(&self) -> boolReturns true if all flags are currently set.
pub fn intersects(&self, other: PollEvents) -> bool
pub fn intersects(&self, other: PollEvents) -> boolReturns true if there are flags common to both self and other.
pub fn contains(&self, other: PollEvents) -> bool
pub fn contains(&self, other: PollEvents) -> boolReturns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: PollEvents)
pub fn insert(&mut self, other: PollEvents)Inserts the specified flags in-place.
pub fn remove(&mut self, other: PollEvents)
pub fn remove(&mut self, other: PollEvents)Removes the specified flags in-place.
pub fn toggle(&mut self, other: PollEvents)
pub fn toggle(&mut self, other: PollEvents)Toggles the specified flags in-place.