[−][src]Struct zmq::CurveKeyPair
A CURVE key pair generated by 0MQ.
Note that for API consistency reasons, since version 0.9, the key pair is represented in the binary form. This is in contrast to libzmq, which returns the z85-encoded representation.
Fields
public_key: [u8; 32]
secret_key: [u8; 32]
Methods
impl CurveKeyPair[src]
impl CurveKeyPairpub fn new() -> Result<CurveKeyPair>[src]
pub fn new() -> Result<CurveKeyPair>Create a new key pair.